@@ -1,6 +1,8 @@
 import json
 import sys
 import os
+from aiconfig.callback import CallbackEvent, CallbackManager
+from .default_parsers.hf import HuggingFaceTextGenerationParser
 import requests
 from typing import ClassVar, Dict, List, Optional
 
@@ -32,6 +34,8 @@ gpt_models = [
 for model in gpt_models:
     ModelParserRegistry.register_model_parser(DefaultOpenAIParser(model))
 ModelParserRegistry.register_model_parser(PaLMChatParser())
+ModelParserRegistry.register_model_parser(PaLMTextParser())
+ModelParserRegistry.register_model_parser(HuggingFaceTextGenerationParser())
 
 class AIConfigRuntime(AIConfig):
     # A mapping of model names to their respective parsers
@@ -40,6 +44,8 @@ class AIConfigRuntime(AIConfig):
     def __init__(self, **kwargs):
         super().__init__(**kwargs)
         self.file_path = None
+        # AIConfigRuntime will always have a callback manager. Ae default one is be created when initialized.
+        self.callback_manager = CallbackManager.create_default_manager()
 
     @classmethod
     def create(
@@ -134,8 +140,12 @@ class AIConfigRuntime(AIConfig):
         returns:
             Prompt | List[Prompt]: A prompt or list of prompts representing the input data
         """
+        event = CallbackEvent("on_serialize_start", __name__, {model_name: model_name, "data": data, "prompt_name": prompt_name, "params": params})
+        await self.callback_manager.run_callbacks(event)
+
         if not params:
             params = {}
+
         model_parser = ModelParserRegistry.get_model_parser(model_name)
         if not model_parser:
             raise ValueError(
@@ -143,6 +153,9 @@ class AIConfigRuntime(AIConfig):
             )
 
         prompts = await model_parser.serialize(prompt_name, data, self, params)
+
+        event = CallbackEvent("on_serialize_complete", __name__, {"result": prompts})
+        await self.callback_manager.run_callbacks(event)
         return prompts
 
     async def resolve(
@@ -161,8 +174,12 @@ class AIConfigRuntime(AIConfig):
         Returns:
             str: The resolved prompt.
         """
+        event = CallbackEvent("on_resolve_start", __file__, {"prompt_name": prompt_name, "params": params})
+        await self.callback_manager.run_callbacks(event)
+
         if not params:
             params = {}
+
         if prompt_name not in self.prompt_index:
             raise IndexError(
                 "Prompt not found in config, available prompts are:\n {}".format(
@@ -175,7 +192,9 @@ class AIConfigRuntime(AIConfig):
         model_provider = AIConfigRuntime.get_model_parser(model_name)
 
         response = await model_provider.deserialize(prompt_data, self, params)
-
+        
+        event = CallbackEvent("on_resolve_complete", __name__, {"result": response})
+        await self.callback_manager.run_callbacks(event)
         return response
 
     async def run(
@@ -195,6 +214,9 @@ class AIConfigRuntime(AIConfig):
         Returns:
             object: The response object returned by the AI-model's API.
         """
+        event = CallbackEvent("on_run_start", __name__, {"prompt_name": prompt_name, "params": params, "options": options, "kwargs": kwargs})
+        await self.callback_manager.run_callbacks(event)
+
         if not params:
             params = {}
 
@@ -209,7 +231,10 @@ class AIConfigRuntime(AIConfig):
         model_name = self.get_model_name(prompt_data)
         model_provider = AIConfigRuntime.get_model_parser(model_name)
 
-        response = await model_provider.run(prompt_data, self, options, params, **kwargs)
+        response = await model_provider.run(prompt_data, self, options, params, callback_manager = self.callback_manager, **kwargs)
+
+        event = CallbackEvent("on_run_complete", __name__, {"result": response})
+        await self.callback_manager.run_callbacks(event)
         return response
 
     #
@@ -226,9 +251,11 @@ class AIConfigRuntime(AIConfig):
             json_config_filepath (str, optional): The file path to the JSON configuration file.
                 Defaults to "aiconfig.json".
         """
+        # AIConfig json should only contain the core data fields. These are auxiliary fields that should not be persisted
         exclude_options = {
             "prompt_index": True, 
-            "file_path": True
+            "file_path": True,
+            "callback_manager": True,
         }
 
         if not include_outputs:
@@ -294,3 +321,8 @@ class AIConfigRuntime(AIConfig):
                 )
             )
         return ModelParserRegistry.get_model_parser(model_id)
+
+    def set_callback_manager(self, callback_manager: CallbackManager):
+        if callback_manager is None:
+            raise ValueError("callback_manager cannot be None. Create a new CallbackManager with No callbacks instead.")
+        self.callback_manager = callback_manager
\ No newline at end of file
