@@ -134,7 +134,7 @@ class OpenAIInference(ParameterizedModelParser):
             prompts[len(prompts) - 1].name = prompt_name
 
         event = CallbackEvent("on_serialize_complete", __name__, {"result": prompts})
-        ai_config.callback_manager.run_callbacks(event)
+        await ai_config.callback_manager.run_callbacks(event)
         return prompts
 
     async def deserialize(
@@ -242,10 +242,12 @@ class OpenAIInference(ParameterizedModelParser):
 
         completion_data["stream"] = stream
 
-        response = openai.ChatCompletion.create(**completion_data)
+        response = openai.chat.completions.create(**completion_data)
         outputs = []
 
         if not stream:
+            # # OpenAI>1.0.0 uses pydantic models for response
+            response = response.model_dump(exclude_none=True)
             response_without_choices = {
                 key: copy.deepcopy(value) for key, value in response.items() if key != "choices"
             }
@@ -265,7 +267,9 @@ class OpenAIInference(ParameterizedModelParser):
             outputs = {}
             messages = {}
             for chunk in response:
-                # streaming only returns one chunk, one choice at a time. The order in which the choices are returned is not guaranteed.
+                # OpenAI>1.0.0 uses pydantic models. Chunk is of type ChatCompletionChunk; type is not directly importable from openai Library, will require some diffing
+                chunk = chunk.model_dump(exclude_none=True)
+                # streaming only returns one chunk, one choice at a time (before 1.0.0). The order in which the choices are returned is not guaranteed.
                 messages = multi_choice_message_reducer(messages, chunk)
 
                 for i, choice in enumerate(chunk["choices"]):
